# eudist

eudist is a library to caculate EUclidean DISTances.

eudist can calculate for example the distance between a point and a
plane in 3D.  A version with the signed distance is also available,
which can be used to check whether two points are on the same side of
the plane.

It can also be used to check if a point is within a polygon, using the
`winding_number` calculation.  It can also for 2D meshes calculate in
which cell a point is.
